/*++

Copyright (c) 2009
Lysann Kessler, Stephanie Platz, Thomas Klingbeil, Philipp Tessenow, Frank Schlegel;
Michael Haupt, Michael Perscheid, Robert Hirschfeld;
Software Architecture Group, Hasso-Plattner-Institut, University of Potsdam, Germany

This software is published under MIT license.
It uses phidget library by Phidgets Inc. (http://phidgets.com).
See ../../../../license.pdf for more information.

Module Name:

	PhidgetCompSimpleLED.c

Abstract:

	This file contains methods for a Phidget Component SimpleLED. 
	A component SimpleLED can belong to several phidgets e.g. the phidget RFID.
	Only if one of these phidgets is attached the component is useable.	Use
	phidget_GetDeviceClass(pointerToPhidget) to call the specific phidget methods
	in phidget21 API.

--*/

#include "PhidgetCompSimpleLED.h"

//////////////////////////////////////////////////////////////////////////
// methods

//
// Gets the current state (on or off) of a component simple LED with the
// corresponding index.
// Use id to identify the owning phidget.
//
BOOL phidgetCompSimpleLED_IsOn(PhidgetId id)
{
	BOOL bValue = FALSE;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, bValue);

	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
	case PHIDCLASS_RFID:
		CPhidgetRFID_getLEDOn( ((PhidgetRFID*) pPhidget)->handle, &bValue);
		break;

	default:
		IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompSimpleLED_IsOn.", phidget_GetDeviceClass(pPhidget)));
	}

	return bValue > 0;
}

//
// Sets the state of a component TextLCD with the corresponding index. Set
// to true if the TextLCD shouble be on.
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompSimpleLED_SetState(PhidgetId id, int iState)
{
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);

	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
	case PHIDCLASS_RFID:
		return CPhidgetRFID_setLEDOn ( ((PhidgetRFID*) pPhidget)->handle, iState ) == 0;

	default:
		IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompSimpleLED_SetState.", phidget_GetDeviceClass(pPhidget)));
		return FALSE;
	}
}
